<?php
/**
 * Theme functions file
 *
 * DO NOT MODIFY THIS FILE. Make a child theme instead: http://codex.wordpress.org/Child_Themes
 *
 * @package Ideas
 * @author AppThemes
 */

// Constants
define( 'IDEAX_VERSION', '1.3.1' );

define( 'IDEAX_PTYPE', 'idea' );
define( 'IDEAX_CATEGORY', 'idea_category' );
define( 'IDEAX_TAG', 'idea_tag' );
define( 'IDEAX_STATUS', 'idea_status' );

define( 'APP_TD', 'ideas' );

// Framework
require dirname(__FILE__) . '/framework/load.php';

$load_files = array(
	'utils.php',
	'options.php',
	'admin-bar.php',
	'capabilities.php',
	'core.php',
	'comments.php',
	'email.php',
	'header.php',
	'idea-form.php',
	'idea-status.php',
	'template-tags.php',
	'users.php',
	'views.php',
	'widgets.php',
);
appthemes_load_files( dirname( __FILE__ ) . '/includes/', $load_files );

$load_classes = array(
	'APP_User_Profile',
	'IDEAX_Blog_Archive',
	'IDEAX_Contact',
	'IDEAX_Idea_Add',
	'IDEAX_Idea_Archive',
	'IDEAX_Idea_Author',
	'IDEAX_Idea_Edit',
	'IDEAX_Idea_Filter',
	'IDEAX_Idea_Front',
	'IDEAX_Idea_Search',
	'IDEAX_Idea_Single',
	'IDEAX_Profile_Edit',
	'IDEAX_Single',
);
appthemes_add_instance( $load_classes );

// Admin only
if ( is_admin() ) {
	require_once( APP_FRAMEWORK_DIR . '/admin/importer.php' );

	$load_files = array(
		'admin.php',
		'dashboard.php',
		'idea-list.php',
		'idea-single.php',
		'install.php',
		'importer.php',
		'settings.php',
		'updates.php',
	);
	appthemes_load_files( dirname( __FILE__ ) . '/includes/admin/', $load_files );

	$load_classes = array(
		'APP_System_Info',
		'IDEAX_Dashboard',
		'IDEAX_Idea_Official_Response_Meta',
		'IDEAX_Idea_Internal_Notes',
		'IDEAX_Votes_Meta',
		'IDEAX_Settings_Admin' => $ideax_options,
	);
	appthemes_add_instance( $load_classes );

}

add_theme_support( 'app-versions', array(
	'update_page'     => 'admin.php?page=app-settings&firstrun=1',
	'current_version' => IDEAX_VERSION,
	'option_key'      => 'ideax_version',
) );

add_theme_support( 'app-wrapping' );

add_theme_support( 'app-search-index' );

// Use a custom image size for featured images, displayed on blog posts.
add_theme_support( 'post-thumbnails' );
set_post_thumbnail_size( 175, 9999 ); // Unlimited height, soft crop

// Adds RSS feed links to <head> for posts and comments.
add_theme_support( 'automatic-feed-links' );

// Adds support for changing background color
add_theme_support( 'custom-background', array(
	'default-color' => '787C84',
	'default-image' => get_template_directory_uri() . '/images/bg.jpg',
) );

add_theme_support( 'app-login', array(
	'login'    => 'form-login.php',
	'register' => 'form-registration.php',
	'recover'  => 'form-password-recovery.php',
	'reset'    => 'form-password-reset.php',
) );

// Our theme handles the customer header in ideax_display_logo()
add_theme_support( 'custom-header', array(
	'default-image'          => '%s/images/ideas-logo.png',
	'width'                  => 200,
	'height'                 => 70,
	'flex-height'            => true,
	'flex-width'             => true,
	'default-text-color'     => 'blank',
	'header-text'            => true,
	'uploads'                => true,
	'wp-head-callback'       => '',
	'admin-head-callback'    => '',
	'admin-preview-callback' => '',
) );

add_theme_support( 'app-open-graph', array(
	'default_image' => ( get_header_image() ) ? get_header_image() : appthemes_locate_template_uri( 'images/ideas-logo.png' ),
) );


APP_Mail_From::init( array(
	'name' => $ideax_options->from_name,
	'email' => $ideax_options->from_email,
) );

if ( ! isset( $content_width ) )
	$content_width = 620;

// Taxonomies need to be registered before the post type, in order for the rewrite rules to work
add_action( 'init', 'ideax_register_taxonomies', 8 );
add_action( 'init', 'ideax_register_post_types', 9 );

// Flush rewrite rules if the related transient is set
add_action( 'init', 'ideax_check_rewrite_rules_transient', 10 );

add_action( 'wp_enqueue_scripts', 'ideax_add_style' );
add_action( 'wp_enqueue_scripts', 'ideax_add_scripts' );

add_action( 'after_setup_theme', 'ideax_setup_theme' );

add_filter( 'body_class', 'ideax_body_class' );

add_filter( 'excerpt_more', 'ideax_excerpt_more' );
add_filter( 'excerpt_length', 'ideax_excerpt_length' );
add_filter( 'the_excerpt', 'strip_tags' );

add_filter( 'login_headerurl', 'ideax_login_logo_url' );
add_filter( 'login_headertitle', 'ideax_login_logo_url_title' );

// Pings 'update services' while publish listing.
add_action( 'publish_' . IDEAX_PTYPE, '_publish_post_hook', 5, 1 );

// Add a very low priority action to make sure any extra settings have been added to the permalinks global
add_action( 'admin_init', 'ideax_enable_permalink_settings', 999999 );

appthemes_init();
