<?php

// Email related functions

add_action( 'pending_to_publish', 'ideax_ideas_publish_author_email' );
add_action( 'draft_to_pending', 'ideax_ideas_notify_admins_email' );
add_action( 'draft_to_publish', 'ideax_ideas_notify_admins_email' );

// when an idea is approved, send author an email
function ideax_ideas_publish_author_email( $post ) {
	global $ideax_options;

	if ( IDEAX_PTYPE != $post->post_type )
		return;

	$mailto = get_the_author_meta( 'user_email', $post->post_author );

	// variables that can be used by admin to dynamically fill in email content
	$markup = IDEAX_Settings_Admin::email_markup_for( 'idea_approved_body' );

	$markup_keys = array_keys( $markup );
	$find_replace = _ideax_pre_process_markup( $markup_keys, $post );

	// search and replace any user added variable fields in the subject line
	$subject = stripslashes( $ideax_options->idea_approved_subject );
	$subject = preg_replace( $find_replace['find'], $find_replace['replace'], $subject );
	$subject = preg_replace( "/%.*%/", "", $subject );

	// search and replace any user added variable fields in the body
	$message = stripslashes( $ideax_options->idea_approved_body );
	$message = preg_replace( $find_replace['find'], $find_replace['replace'], $message );
	$message = preg_replace( "/%.*%/", "", $message );

	if ( $ideax_options->allow_html ) {
		$message = wpautop( $message );
		appthemes_send_email( $mailto, $subject, $message );
	} else {
		wp_mail( $mailto, $subject, $message );
	}
}

// when an idea is submitted, send admins an email
function ideax_ideas_notify_admins_email( $post ) {
	global $ideax_options;

	if ( IDEAX_PTYPE != $post->post_type )
		return;

	$args = array(
		'role' => 'administrator',
	);
	$recipients = get_users( $args );

	$user_login = get_the_author_meta( 'user_login', $post->post_author );

	if ( $ideax_options->moderate_ideas ) {
		$subject = __( 'New idea submission - review required', APP_TD );
		$actions = __( 'Please review and approve if it meets our guidelines.', APP_TD );
	} else {
		$subject = __( 'New idea submission', APP_TD );
		$actions = __( 'You can view it by clicking the link bellow.', APP_TD );
	}

	$message  = html( 'p', sprintf( __( 'Hi %s,', APP_TD ), 'admin' ) ) . PHP_EOL;
	$message .= html( 'p', sprintf( __( 'A new idea called, "%1$s" has been submitted by %2$s.', APP_TD ), $post->post_title, $user_login ) ) . PHP_EOL;
	$message .= html( 'p', $actions . '<br />' . get_edit_post_link( $post->ID, '' ) ) . PHP_EOL;
	$message .= html( 'p',
		__( 'Regards,', APP_TD ) . '<br />' .
		sprintf( __( 'Your %s Team', APP_TD ), get_bloginfo( 'name' ) ) . '<br />' .
		home_url( '/' )
	) . PHP_EOL;

	foreach ( $recipients as $recipient ) {
		appthemes_send_email( $recipient->user_email, $subject, $message );
	}
}

// when an idea status taxonomy changes, send author an email - triggered on 'pre_post_update'
function ideax_ideas_status_change_email( $post, $status_old_id, $status_new_id ) {
	global $ideax_options;

	$mailto = get_the_author_meta( 'user_email', $post->post_author );
	$author = get_the_author_meta( 'display_name', $post->post_author );

	// get the status tax object so we can display nice name
	$status_old = get_term_by( 'id', $status_old_id, IDEAX_STATUS );
	$status_new = get_term_by( 'id', $status_new_id, IDEAX_STATUS );

	$subject = __( 'Your idea had a status change', APP_TD );

	$message  = html( 'p', sprintf( __( 'Hi %s,', APP_TD ), $author ) ) . PHP_EOL;
	$message .= html( 'p', sprintf( __( 'Your "%1$s" idea, status just changed from "%2$s" to "%3$s".', APP_TD ), $post->post_title, $status_old->name, $status_new->name ) ) . PHP_EOL;
	$message .= html( 'p', __( 'View your idea:', APP_TD ) . '<br />' . get_permalink( $post->ID ) ) . PHP_EOL;
	$message .= html( 'p',
		__( 'Regards,', APP_TD ) . '<br />' .
		sprintf( __( 'Your %s Team', APP_TD ), get_bloginfo( 'name' ) ) . '<br />' .
		home_url( '/' )
	) . PHP_EOL;

	appthemes_send_email( $mailto, $subject, $message );

}

function _ideax_pre_process_markup( $markup, $idea ) {

	foreach ( $markup as $key ) {

		switch( $key ) {
			case '%ideatitle%':
				$value = $idea->post_title;
				break;
			case '%ideaurl%':
				$value = get_permalink( $idea->ID );
				break;
			case '%authorname%':
				$value = get_the_author_meta( 'display_name', $idea->post_author );
				break;
			case '%siteurl%':
				$value = home_url( '/' );
				break;
			case '%sitename%':
				$value = get_bloginfo( 'name' );
				break;
			case '%loginurl%':
				$value = wp_login_url();
				break;
		}

		$keys[] = "/$key/i";
		$values[] = $value;

	}

	$find_replace = array(
		'find' => $keys,
		'replace' => $values
	);

	return $find_replace;
}
