<?php

// Header functions

add_action( 'appthemes_after_header', 'ideax_search_bar' );
add_action( 'ideax_nav_menu_profile', 'ideax_nav_menu_profile' );
add_action( 'ideax_menu_profile_actions', 'ideax_menu_profile_actions' );

function ideax_search_bar() {
	get_template_part( 'search-bar' );
}

function ideax_nav_menu_profile( $args = '' ) {
	global $current_user;

	$html_actions = '';
	$args = array(
		'container_class' => 'profile-info fr clear',
		'show_gravatar' => 1
	);

	if ( is_user_logged_in() ) {
		get_currentuserinfo();
		$username = html_link( get_author_posts_url( $current_user->ID ), $current_user->display_name );

		if ( $args['show_gravatar'] ) {
			$html_avatar = get_avatar( $current_user->ID, 32 );
		}

		$actions = array(
			'edit-profile' => html( 'a', array( 'href' => appthemes_get_edit_profile_url() ), __( 'Edit Profile', APP_TD ) ),
			'logout' => html( 'a', array( 'href' => wp_logout_url() ), __( 'Logout', APP_TD ) ),
		);
	} else {
		$html_avatar = get_avatar( 0, 32 );
		$username = __( 'Welcome, visitor!', APP_TD );

		$actions = array(
			'login' => html( 'a', array( 'href' => wp_login_url() ), __( 'Login', APP_TD ) ),
		);
	}
	$html_username = html( 'div', array( 'class' => 'profile-info-username' ), $username );

	$actions = apply_filters( 'ideax_menu_profile_actions', $actions, $current_user );

	foreach ( $actions as $class => $action ) {
		$html_actions .= html( 'span', array( 'class' => $class ), ' ' . $action );
	}
	$html_actions = html( 'div', array( 'class' => 'profile-info-actions' ), $html_actions );

	echo html( 'div', array( 'class' => $args['container_class'] ),
		$html_avatar .   // echo avatar
		$html_username . // echo username
		$html_actions    // echo actions
	);
}

function ideax_menu_profile_actions( $actions ) {
	if ( ! is_user_logged_in() && get_option( 'users_can_register' ) ) {
		$actions['register'] = wp_register( '', '', false );
	}

	return $actions;
}

function ideax_display_logo() {

	$header_image = get_header_image();
?>
	<h1 id="site-title" class="custom-header-image">
		<?php if ( $header_image ) { ?>
			<a title="<?php bloginfo( 'title' ); ?>" href="<?php echo esc_url( home_url( '/' ) ); ?>" class="custom-header-image" style="height:<?php echo get_custom_header()->height; ?>px;width:<?php echo get_custom_header()->width; ?>px;background: transparent url('<?php echo $header_image; ?>') no-repeat 0 0;display: block"></a>
		<?php } ?>
		<?php if ( display_header_text() ) { ?>
			<a title="<?php bloginfo( 'title' ); ?>" href="<?php echo esc_url( home_url( '/' ) ); ?>" class="custom-header-image" style="color:#<?php echo get_header_textcolor(); ?>;"><?php bloginfo( 'title' ); ?></a>
		<?php } ?>
	</h1>
<?php
}
