<?php

// Ideas status changing related functions

add_action( 'pending_to_publish', 'ideax_update_idea_start_date' );
add_action( 'draft_to_publish', 'ideax_update_idea_start_date' );

// update Search Index
add_action( 'save_post', array( 'APP_Search_Index', 'save_post' ), 100, 2 );


function ideax_update_idea_start_date( $post ) {

	if ( $post->post_type == IDEAX_PTYPE ) {
		wp_update_post( array(
			'ID' => $post->ID,
			'post_date' => current_time( 'mysql' )
		) );
	}
}

// updates a specific idea status based on the 'moderate_ideas' option value
function ideax_maybe_publish_idea( $idea_id ) {
	global $ideax_options;
	if ( $ideax_options->moderate_ideas ) {
		$status = 'pending';
	} else {
		$status = 'publish';
	}
	ideax_update_post_status( $idea_id, $status );
}

function ideax_update_post_status( $post_id, $new_status ) {
	wp_update_post( array(
		'ID' => $post_id,
		'post_status' => $new_status
	) );
}

// avoid invalid 'open' status slugs by defaulting to 'open'
function ideax_status_slug( $status ) {
	global $ideax_options;

	if ( ! $ideax_options->open_status_slug ) {
		$slug = 'open';
	}

	switch( $status ) {
		case 'open' :
			if ( empty( $slug ) ) {
				$slug = explode( ',', $ideax_options->open_status_slug );
				$slug = reset( $slug );
			}
			break;
		default:
			$slug = $status;
	}
	return $slug;
}

// check if a specific idea is 'open'
function ideax_is_idea_open( $idea_id ) {
	global $ideax_options;

	$terms = get_the_terms( $idea_id, IDEAX_STATUS );

	if ( ! $terms || 'publish' != get_post_status( $idea_id ) )
		return false;

	$open_status_slugs = $ideax_options->open_status_slug;
	$open_status_slugs = strtolower( str_replace( ' ', '' , $open_status_slugs ) );
	$open_status_slugs = explode( ',', $open_status_slugs );
	$open_status_slugs = array_map( 'trim' , $open_status_slugs );

	foreach ( $terms as $term ) {
		if ( in_array( strtolower( $term->slug ), $open_status_slugs ) ) {
			return true;
		}
	}

	return false;
}

// reset a specific idea votes to 0
function ideax_reset_votes( $idea_id ) {
	update_post_meta( $idea_id, '_ideax_idea_total_votes', 0 );
}
