<?php

// Users related functions

add_action( 'user_register', 'ideax_additional_user_meta' );

add_filter( 'manage_users_columns', 'ideax_add_user_columns' );
add_filter( 'manage_users_custom_column', 'ideax_add_user_column_value', 10, 3 );

function ideax_additional_user_meta( $user_id ) {
	global $wpdb, $ideax_options;

	$firstname = $lastname = '';
	if ( ! empty( $_POST['firstname'] ) )
		$firstname = $_POST['firstname'];

	if ( ! empty( $_POST['lastname'] ) )
		$lastname = $_POST['lastname'];

	$userinfo = array(
		'ID' => $user_id,
		'first_name' => $firstname,
		'last_name' => $lastname,
		'role' => 'contributor'
	);

	ideax_reset_user_votes( $user_id );

	// Update the WordPress User object with additional meta
	wp_update_user( $userinfo );
}

// display the custom user columns
function ideax_add_user_columns( $columns ) {
	// remove 'posts' column
	unset( $columns['posts'] );

	$columns['ideas'] = __( 'Ideas', APP_TD );
	$columns['total_votes'] = __( 'Votes', APP_TD );
	$columns['votes_left'] = __( 'Votes Left', APP_TD );

	return $columns;
}

// display the custom user column values
function ideax_add_user_column_value( $value, $column_name, $user_id ) {
	global $ideax_options, $wp_list_table, $users_ideas_counts;

	$user = get_userdata( $user_id );

	if ( $column_name == 'ideas' ) {
		if ( ! isset( $users_ideas_counts ) ) {
			$users_ideas_counts = count_many_users_posts( array_keys( $wp_list_table->items ), IDEAX_PTYPE );
		}

		if ( ! isset( $users_ideas_counts[ $user_id ] ) || $users_ideas_counts[ $user_id ] == 0 ) {
			return 0;
		}

		$url = add_query_arg( array( 'post_type' => IDEAX_PTYPE, 'author' => $user_id ), admin_url( 'edit.php' ) );
		return html( 'a', array( 'href' => $url, 'class' => 'edit', 'title' => esc_attr__( 'View ideas by this author', APP_TD ) ), $users_ideas_counts[ $user_id ] );
	} elseif ( $column_name == 'total_votes' ) {
		return intval( get_the_author_meta( 'ideax_user_votes_total', $user_id ) );
	} elseif ( $column_name == 'votes_left' ) {
		return intval( ideax_user_votes_left( $user_id ) . ' / ' . $ideax_options->votes_per_user );
	} else {
		return $value;
	}
}

// get total votes left for a specific user
function ideax_user_votes_left( $user_id ) {
	global $ideax_options;

	$votes_per_user = $ideax_options->votes_per_user;
	$votes_left = intval( get_the_author_meta( 'ideax_user_votes_left', $user_id ) );

	if ( $votes_left > $votes_per_user )
		$votes_left = 0;

	return intval( $votes_left );
}

// outputs a table with the user voting list
function ideax_user_voted_list( $user ) {
	$voted_ideas = maybe_unserialize( get_the_author_meta( 'ideax_user_votes', $user->ID ) );

	if ( ! $voted_ideas ) {
		echo html( 'span', __( 'None', APP_TD ) );
		return;
	}
?>
	<table id="voted-ideas-table" class="form-table" border="1" cellspacing="1">
		<tr>
			<th><strong><?php _e( 'Idea', APP_TD ); ?></strong></th>
			<th><strong><?php _e( 'Votes', APP_TD ); ?></strong></th>
			<th><strong><?php _e( 'Date', APP_TD ); ?></strong></th>
		</tr>

<?php

		if ( ! $voted_ideas ) {
			echo __( 'None', APP_TD );
			return;
		}

		foreach ( $voted_ideas as $idea_id => $data ) {
?>
			<tr>
				<td><?php echo get_the_title( $idea_id ); ?></td>
				<td width=2%><?php echo $data['votes']; ?></td>
				<td width=15%><?php echo date_i18n( get_option('date_format'), strtotime( $data['date'] ) ); ?></td>
			</tr>
<?php
		}
?>
	</table>
<?php
}

// returns the ideas for a specific user
function ideax_get_user_ideas( $user_id, $self = false ) {
	global $ideax_options;

	$args = array(
		'post_type' => IDEAX_PTYPE,
		'author' => $user_id,
		'paged' => get_query_var( 'paged' ),
		'posts_per_page' => $ideax_options->ideas_per_page
	);

	if ( $self ) {
		$args['post_status'] = array( 'publish', 'pending' );
	} else {
		$args['post_status'] = array( 'publish' );
	}

	$query = new WP_Query( $args );

	return $query;
}

function ideax_is_own_dashboard() {
	global $wp_query;
	$dashboard_author = $wp_query->get( 'dashboard_author' );

	if ( $dashboard_author == 'self' ) {
		return true;
	} else {
		return false;
	}
}

function ideax_is_dashboard_author() {
	global $wp_query;
	$dashboard_author = $wp_query->get( 'dashboard_author' );

	if ( $dashboard_author == 'self' ) {
		return true;
	} else {
		return false;
	}
}

function ideax_get_dashboard_author() {
	global $wp_query;
	$dashboard_author = $wp_query->get( 'author_name' );

	if ( $dashboard_author == 'self' ) {
		$user = wp_get_current_user();
	} else {
		$user = get_user_by( 'slug', $dashboard_author );
	}

	return $user;
}

// get a list of voters based on the passed arguments
function ideax_get_voters( $args = array() ) {
	$args = wp_parse_args( $args );
	$user_search = new WP_User_Query( $args );

	return $user_search;
}


// function call from within widgets.php
function ideax_widget_show_voters( $number ) {
	global $post;

	// get all voter data
	$data = get_post_meta( $post->ID, '_ideax_post_votes', true );

	if ( $data ) :
		// only show the number of voters set by widget
		$chunks = array_chunk( $data['users'], $number, true );
	?>

		<div class="widget-content">
			<ul>
			<?php foreach ( $chunks[0] as $key => $value ) { ?>
				<li>
					<?php echo get_avatar( $key, 32 ); ?>
					<?php ( get_current_user_id() != $key ? the_idea_author( $key ): the_idea_author( $key, __( 'You', APP_TD ) ) ); ?> - <span class="time-ago"><?php printf( __( '%s ago', APP_TD ), human_time_diff( $value['added'], time() ) ); ?></span>
				</li>
			<?php } ?>
			</ul>
		</div>

	<?php else : ?>

		<div class="widget_votes-count">
			<span><?php _e( 'No votes from anyone yet.', APP_TD ); ?></span>
		</div>

	<?php endif; ?>

<?php
}


// reset the votes for a specific user
function ideax_reset_user_votes( $user_id ) {
	global $ideax_options;

	$votes_left = $ideax_options->votes_per_user;

	// reset casted votes for the user
	update_user_meta( $user_id, 'ideax_user_votes_total', 0 );
	update_user_meta( $user_id, 'ideax_user_votes_last_reset_date', time() );
	update_user_meta( $user_id, 'ideax_user_votes_left', $votes_left );
}
