<?php

// These utility functions can go away at any time. Don't rely on them.

//add_filter( 'get_avatar', 'ideax_get_avatar', 10, 5 );
add_filter( 'wp_nav_menu_objects', 'ideax_update_nav_permalinks', 10, 2 );

function ideax_get_avatar( $avatar, $id_or_email, $size, $default, $alt ) {

	$class = 'gravatar avatar';

	if ( 32 == $size ) {
		$class .= ' sidebar-gravatar';
	}
	$avatar = str_replace( "class='avatar", "class='$class", $avatar );

	return $avatar;
}

function ideax_update_nav_permalinks( $items, $args ) {
	global $ideax_options;

	$url = home_url( '/' . $ideax_options->ideas_permalink );
	foreach ( $items as $item ) {

		if ( ! empty( $item->xfn ) && 'latest-ideas' == $item->xfn )
			$item->url = $url;

		$nav_items[] = $item;
	}

	return $nav_items;
}

function ideax_show_search_query_var( $qv ) {
	echo ideax_get_search_query_var( $qv );
}

function ideax_get_search_query_var( $qv ) {
	return stripslashes( esc_attr( trim( get_query_var( $qv ) ) ) );
}

function get_blog_page_title() {
	return get_the_title( IDEAX_Blog_Archive::get_id() );
}

// temporary workaround for wordpress bug #9296 http://core.trac.wordpress.org/ticket/9296
// Although there is a hook in the options-permalink.php to insert custom settings,
// it does not actually save any custom setting which is added to that page.
function ideax_enable_permalink_settings() {
	global $new_whitelist_options;

	// save hook for permalinks page
	if ( isset( $_POST['permalink_structure'] ) || isset( $_POST['category_base'] ) ) {
		check_admin_referer( 'update-permalink' );

		$option_page = 'permalink';

		$capability = 'manage_options';
		$capability = apply_filters( "option_page_capability_{$option_page}", $capability );

		if ( ! current_user_can( $capability ) )
			wp_die( __( 'Cheatin&#8217; uh?', APP_TD ) );

		// get extra permalink options
		$options = $new_whitelist_options[ $option_page ];

		if ( $options ) {
			foreach ( $options as $option ) {
				$option = trim( $option );
				$value = null;

				if ( isset( $_POST[ $option ] ) )
					$value = $_POST[ $option ];

				if ( ! is_array( $value ) )
					$value = trim( $value );

				$value = stripslashes_deep( $value );

				// get the old values to merge
				$db_option = get_option( $option );

				if ( is_array( $db_option ) ) {
					update_option( $option, array_merge( $db_option, $value ) );
				} else {
					update_option( $option, $value );
				}

				// flush rewrite rules using a transient
				set_transient( 'ideax_flush_rewrite_rules', 1, 300 );
			}
			//Yes, we need to do this now, come back to this and make the transient work in the right timing. 
			flush_rewrite_rules();
		}

		/**
		 * Handle settings errors
		 */
		set_transient( 'settings_errors', get_settings_errors(), 30 );
	}
}

// temporarly use a transient to flush the rewrite rules
function ideax_check_rewrite_rules_transient() {

	if ( get_transient( 'ideax_flush_rewrite_rules' ) ) {
		delete_transient( 'ideax_flush_rewrite_rules' );
		// files required for hard reset of rewrite rules
		require_once( ABSPATH . 'wp-admin/includes/file.php' );
		require_once( ABSPATH . 'wp-admin/includes/misc.php' );
		flush_rewrite_rules();
	}

	if ( isset( $_GET['firstrun'] ) )
		set_transient( 'ideax_flush_rewrite_rules', 1, 300 );

}

function ideax_excerpt_more() {
	return '&hellip;';
}

function ideax_excerpt_length() {
	return 45;
}

function ideax_register_sidebar( $id, $name, $description = '', $class = '' ) {
	register_sidebar( array(
		'id' => $id,
		'name' => $name,
		'description' => $description,
		'before_widget' => '<aside id="%1$s" class="widget %2$s ' . $class . '">',
		'after_widget' => "</aside>",
		'before_title' => '<div class="widget-head"><h3>',
		'after_title' => '</h3></div>',
	) );
}

function ideax_truncate( $string, $limit, $link, $break = '', $pad = '...' ) {

	// return with no change if string is shorter than $limit
	if ( strlen( $string ) <= $limit )
		return $string;

	$string = substr( $string, 0, $limit );

	if ( false !== ( $breakpoint = strrpos( $string, $break ) ) ) {
		$string = substr( $string, 0, $breakpoint );
	}

	return $string . $pad . $link;
}
